# WPM Probability Distribution #

-------------------------------------------------------------------------------

WPM Probability Distribution is a package to create probability distributions
objects. On this current version (0.1), the available distributions are the
following:
  * Gaussian Distribution
  * Binomial Distribution

## Installation ##
The source code is hosted on GitHub at: [https://github.com/WisnuMulya/Probability-Distribution-Package](https://github.com/WisnuMulya/Probability-Distribution-Package). 

    # PyPI
	pip install wpm-probability

## Usage ##
After installation, you can import the package as following:

    # Importing the Gaussian and Binomial class
	from wpm_probability import Gaussian, Binomial

## Contribution ##
If you want to contribute to this project and make it beter, your help is very
welcome.

The following is the general guide on how to contribute to this project:
   1. Fork this project & clone it on your local machine
   2. Create an *upstream* remote and sync your local copy before you branch
   3. Branch for each piece of work
   4. Do the work
   5. Push to your origin repository
   6. Create a new pull request on GitHub

## License ##
The content of thic package is covered under the [MIT License](./license.txt).
